# -*- coding: utf-8 -*-
# Generated by Django 1.11.8 on 2018-04-03 16:06
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('notifications', '0002_auto_20171020_0913'),
    ]

    operations = [
        migrations.CreateModel(
            name='Action',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('kind', models.CharField(db_index=True, max_length=20)),
                ('text', models.CharField(max_length=100)),
                ('url', models.URLField(max_length=512)),
                ('ordering', models.PositiveIntegerField(default=0)),
                ('notification', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='actions', to='notifications.Notification')),
            ],
            options={
                'ordering': ('ordering',),
            },
        ),
        migrations.AlterUniqueTogether(
            name='action',
            unique_together=set([('url', 'notification')]),
        ),
    ]
