# Generated by Django 2.1.2 on 2019-03-04 11:22

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('notifications', '0004_auto_20190225_1021'),
    ]

    operations = [
        migrations.AddField(
            model_name='notification',
            name='email',
            field=models.BooleanField(default=True),
        ),
    ]
